summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDan Williams <dcbw@redhat.com>2016-01-20 17:06:07 -0600
committerDan Williams <dcbw@redhat.com>2016-01-20 17:06:33 -0600
commit0512a820cda8e0934ce11339726e66c6dea85d3f (patch)
tree10e51e67cf688a7e622951f03bc460e6df3542fc
parent98c58ca64b7fa80ebe7cf96bcee77c7e9ef02f99 (diff)
downloadModemManager-0512a820cda8e0934ce11339726e66c6dea85d3f.tar.gz
libmm-glib: make C++ happy by not using 'class'
-rw-r--r--libmm-glib/mm-sms-properties.c8
-rw-r--r--libmm-glib/mm-sms-properties.h2
2 files changed, 5 insertions, 5 deletions
diff --git a/libmm-glib/mm-sms-properties.h b/libmm-glib/mm-sms-properties.h
index fb9dbf9e0..4989d59ee 100644
--- a/libmm-glib/mm-sms-properties.h
+++ b/libmm-glib/mm-sms-properties.h
@@ -71,7 +71,7 @@ void mm_sms_properties_set_smsc (MMSmsProperties *self,
void mm_sms_properties_set_validity_relative (MMSmsProperties *self,
guint validity);
void mm_sms_properties_set_class (MMSmsProperties *self,
- gint class);
+ gint message_class);
void mm_sms_properties_set_delivery_report_request (MMSmsProperties *self,
gboolean request);
void mm_sms_properties_set_teleservice_id (MMSmsProperties *self,
diff --git a/libmm-glib/mm-sms-properties.c b/libmm-glib/mm-sms-properties.c
index 93e8b9b56..da4aa804c 100644
--- a/libmm-glib/mm-sms-properties.c
+++ b/libmm-glib/mm-sms-properties.c
@@ -322,18 +322,18 @@ mm_sms_properties_get_validity_relative (MMSmsProperties *self)
/**
* mm_sms_properties_set_class:
* @self: A #MMSmsProperties.
* @class: The message class (0..3), or -1 for invalid/unset class.
*
* Sets the 3GPP message class of the SMS.
*/
void
mm_sms_properties_set_class (MMSmsProperties *self,
- gint class)
+ gint message_class)
{
g_return_if_fail (MM_IS_SMS_PROPERTIES (self));
- g_return_if_fail (class >= -1 && class <= 3);
+ g_return_if_fail (message_class >= -1 && message_class <= 3);
- self->priv->class = class;
+ self->priv->class = message_class;
}
/**
@@ -322,18 +322,18 @@ mm_sms_properties_get_validity_relative (MMSmsProperties *self)
* mm_sms_properties_set_class:
* @self: A #MMSmsProperties.
- * @class: The message class (0..3), or -1 for invalid/unset class.
+ * @message_class: The message class (0..3), or -1 for invalid/unset class.
*
* Sets the 3GPP message class of the SMS.